@@ -6,9 +6,9 @@ cowbuilderroot="/home/neurodebian"
 buildplace="${cowbuilderroot}/build"
 
 # all currently supported dists
-allnddists="nd+debian-stretch nd+debian-buster nd+debian-bullseye nd+debian-sid \
-            nd+ubuntu-xenial nd+ubuntu-bionic nd+ubuntu-focal nd+ubuntu-groovy"
-alldists="$allnddists debian-jessie debian-stretch debian-buster debian-bullseye debian-sid"
+allnddists="nd+debian-stretch nd+debian-buster nd+debian-bullseye nd+debian-bookworm nd+debian-sid \
+            nd+ubuntu-bionic nd+ubuntu-focal nd+ubuntu-impish nd+ubuntu-jammy"
+alldists="$allnddists debian-stretch debian-buster debian-bullseye debian-sid"
 
 # default is debian
 aptcache="${cowbuilderroot}/debian_aptcache"
